=== modified file 'bzrlib/check.py'
--- bzrlib/check.py	2007-09-28 08:18:16 +0000
+++ bzrlib/check.py	2007-10-05 00:44:53 +0000
@@ -32,10 +32,12 @@
 # raising them.  If there's more than one exception it'd be good to see them
 # all.
 
+from bzrlib import errors
 from bzrlib import repository as _mod_repository
+from bzrlib import revision
 from bzrlib.errors import BzrCheckError
 import bzrlib.ui
-from bzrlib.trace import note
+from bzrlib.trace import log_error, note, mutter
 
 class Check(object):
     """Check a repository"""
@@ -97,7 +99,7 @@
              self.repository.bzrdir.root_transport,
              self.repository._format)
         note('%6d revisions', self.checked_rev_cnt)
-        note('%6d versionedfiles', len(self.checked_weaves))
+        note('%6d file-ids', len(self.checked_weaves))
         note('%6d unique file texts', self.checked_text_cnt)
         note('%6d repeated file texts', self.repeated_text_cnt)
         note('%6d unreferenced text ancestors',
@@ -123,7 +125,7 @@
                         note('       * %s', linker)
             if verbose:
                 for file_id, revision_id in self.unreferenced_ancestors:
-                    note('unreferenced ancestor: {%s} in %s', revision_id,
+                    log_error('unreferenced ancestor: {%s} in %s', revision_id,
                         file_id)
         if len(self.inconsistent_parents):
             note('%6d inconsistent parents', len(self.inconsistent_parents))
@@ -190,13 +192,12 @@
                     self.repository.get_transaction())
             # No progress here, because it looks ugly.
             w.check()
-            result = w.check_parents(
-                self.planned_revisions,
-                self.revision_versions.get_text_version,
-                weave_id,
-                revision_parents,
-                self.repository.get_graph(),
-                self.repository.get_inventory)
+
+            weave_checker = self.repository.get_versioned_file_checker(
+                self.planned_revisions, self.revision_versions)
+            result = weave_checker.check_file_version_parents(
+                w, weave_id, revision_parents)
+
             for revision_id, (weave_parents,correct_parents) in result.items():
                 self.inconsistent_parents.append(
                     (revision_id, weave_id, weave_parents, correct_parents))
@@ -248,3 +249,6 @@
         branch.unlock()
     branch_result.report_results(verbose)
     repo_result.report_results(verbose)
+
+
+

=== modified file 'bzrlib/reconcile.py'
--- bzrlib/reconcile.py	2007-10-03 07:45:17 +0000
+++ bzrlib/reconcile.py	2007-10-05 00:44:53 +0000
@@ -368,13 +368,10 @@
             self.pb.update('Fixing text parents', num,
                            len(self.repo.weave_store))
             vf = self.repo.weave_store.get_weave(file_id, transaction)
-            versions_with_bad_parents = vf.check_parents(
-                self.revisions.versions(),
-                revision_versions.get_text_version,
-                file_id,
-                revision_parents,
-                self.repo.get_graph(),
-                self.repo.get_inventory)
+            vf_checker = self.repo.get_versioned_file_checker(
+                self.revisions.versions(), revision_versions)
+            versions_with_bad_parents = vf_checker.check_file_version_parents(
+                vf, file_id, revision_parents)
             if len(versions_with_bad_parents) == 0:
                 continue
             new_vf = self.repo.weave_store.get_empty('temp:%s' % file_id,

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2007-10-03 07:45:17 +0000
+++ bzrlib/repository.py	2007-10-05 00:44:53 +0000
@@ -1452,6 +1452,9 @@
                 [parents_provider, other_repository._make_parents_provider()])
         return graph.Graph(parents_provider)
 
+    def get_versioned_file_checker(self, revisions, revision_versions_cache):
+        return WeaveChecker(revisions, revision_versions_cache, self)
+
     def find_bad_ancestors(self, revision_ids, file_id, versionedfile,
                            revision_versions):
         """Search the versionedfile for ancestors that are not referenced.
@@ -2524,3 +2527,55 @@
                 self._memoized[revision_id] = parents
             parents_list.append(parents)
         return parents_list
+
+
+class WeaveChecker(object):
+
+    def __init__(self, planned_revisions, revision_versions, repository):
+        self.planned_revisions = planned_revisions
+        self.revision_versions = revision_versions
+        self.repository = repository
+        
+    def calculate_file_version_parents(self, revision_id, file_id,
+                                       parents_provider):
+        text_revision = self.revision_versions.get_text_version(
+            file_id, revision_id)
+        if text_revision is None:
+            return None
+        parents_of_text_revision = parents_provider.get_parents(
+            [text_revision])[0]
+        parents_from_inventories = []
+        for parent in parents_of_text_revision:
+            if parent == _mod_revision.NULL_REVISION:
+                continue
+            try:
+                inventory = self.repository.get_inventory(parent)
+            except errors.RevisionNotPresent:
+                pass
+            else:
+                introduced_in = inventory[file_id].revision
+                parents_from_inventories.append(introduced_in)
+        mutter('%r:%r introduced in: %r',
+               file_id, revision_id, parents_from_inventories)
+        graph = self.repository.get_graph()
+        heads = set(graph.heads(parents_from_inventories))
+        mutter('    heads: %r', heads)
+        new_parents = []
+        for parent in parents_from_inventories:
+            if parent in heads and parent not in new_parents:
+                new_parents.append(parent)
+        return new_parents
+
+    def check_file_version_parents(self, weave, file_id, parents_provider):
+        result = {}
+        for num, revision_id in enumerate(self.planned_revisions):
+            correct_parents = self.calculate_file_version_parents(
+                revision_id, file_id, parents_provider)
+            if correct_parents is None:
+                continue
+            text_revision = self.revision_versions.get_text_version(
+                file_id, revision_id)
+            knit_parents = weave.get_parents(text_revision)
+            if correct_parents != knit_parents:
+                result[revision_id] = (knit_parents, correct_parents)
+        return result

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2007-10-03 07:45:17 +0000
+++ bzrlib/versionedfile.py	2007-10-05 00:44:53 +0000
@@ -496,50 +496,6 @@
                     b_marker=TextMerge.B_MARKER):
         return PlanWeaveMerge(plan, a_marker, b_marker).merge_lines()[0]
 
-    def calculate_parents(self, revision_id, get_text_version, file_id,
-            parents_provider, repo_graph, get_inventory):
-        text_revision = get_text_version(file_id, revision_id)
-        if text_revision is None:
-            return None
-        parents_of_text_revision = parents_provider.get_parents(
-            [text_revision])[0]
-        parents_from_inventories = []
-        for parent in parents_of_text_revision:
-            if parent == revision.NULL_REVISION:
-                continue
-            try:
-                inventory = get_inventory(parent)
-            except errors.RevisionNotPresent:
-                pass
-            else:
-                introduced_in = inventory[file_id].revision
-                parents_from_inventories.append(introduced_in)
-        mutter('%r:%r introduced in: %r',
-               file_id, revision_id, parents_from_inventories)
-        heads = set(repo_graph.heads(parents_from_inventories))
-        mutter('    heads: %r', heads)
-        new_parents = []
-        for parent in parents_from_inventories:
-            if parent in heads and parent not in new_parents:
-                new_parents.append(parent)
-        return new_parents
-
-    def check_parents(self, revision_ids, get_text_version, file_id,
-            parents_provider, repo_graph, get_inventory):
-        result = {}
-        for num, revision_id in enumerate(revision_ids):
-            correct_parents = self.calculate_parents(revision_id,
-                    get_text_version, file_id, parents_provider, repo_graph,
-                    get_inventory)
-            if correct_parents is None:
-                continue
-            text_revision = get_text_version(file_id, revision_id)
-            knit_parents = self.get_parents(text_revision)
-            if correct_parents != knit_parents:
-                result[revision_id] = (knit_parents, correct_parents)
-        mutter('    RESULT: %r', result)
-        return result
-
     def find_bad_ancestors(self, revision_ids, get_text_version, file_id,
             parents_provider, repo_graph):
         """Search this versionedfile for ancestors that are not referenced.

